@@ -900,7 +900,9 @@ def pbdDict_bxReposRoot(
 
     gitCloneBase( 'bisos',  'bisos/base', vcMode)
     gitClone( 'bisos/overview',  'bisos/overview', vcMode)
-    gitClone( 'bisos/bsip3',  'bisos/bsip3', vcMode)
+    gitClone( 'bisos/bsip4',  'bisos/bsip4', vcMode)
+    gitClone( 'bisos/bpip1',  'bisos/bpip1', vcMode)
+    gitClone( 'bisos/comeega',  'bisos/comeega', vcMode)        
    
     gitCloneBase( 'blee',  'bx-blee/base',  vcMode)
     gitClone(
